@@ -54,7 +54,7 @@
 #'
 pbmk <- function(x, nsim=1000, pw="Hamed") {
   # Initialize the test parameters
-
+  options(scipen = 999)
   # Time series vector
   x = x
   #Number of simulations
@@ -119,6 +119,7 @@ pbmk <- function(x, nsim=1000, pw="Hamed") {
     slp <- MK.orig[[2]]
     Tau <- MK.orig[[6]]
     S.orig <- MK.orig[[3]]
+    P.orig <-MK.orig[[5]]
     MKpw <- mkttest(xn)
     Zpw <- MKpw[[1]]
     slpPW <- MKpw[[2]]
@@ -135,6 +136,7 @@ pbmk <- function(x, nsim=1000, pw="Hamed") {
     return(c("Z Value"=Z,
              "Sen's Slope"=slp,
              "S"=S.orig,
+             "p"=P.orig,
              "Kendall's Tau"=Tau,
              "BCP Z Value"=Zpw,
              "BCP Sen's Slope"=slpPW,
