@@ -46,7 +46,7 @@
 #'
 tfpwmk <-function(x) {
   # Initialize the test parameters
-
+  options(scipen = 999)
   # Time series vector
   x = x
   # Modified Z statistic after prewhitening
@@ -74,12 +74,12 @@ tfpwmk <-function(x) {
   }
 
   n<-length(x)
-  
+
   #Specify minimum input vector length
   if (n < 3) {
     stop("Input vector must contain at least three values")
   }
-  
+
   # Calculating Sen's slope
   rep(NA, n * (n - 1)/2) -> V
   k = 0
@@ -140,7 +140,7 @@ tfpwmk <-function(x) {
 
   if (S == 0) {
     z = 0
-  }
+  }else
   if (S > 0) {
     z = (S-1)/sqrt(var.S)
   } else {
